#include <libint2.h>
#ifdef __cplusplus
extern "C" {
#endif
void _aB_G__0__K__1___TwoPRep_F__0__G__1___Ab__up_0(const Libint_t* inteval);
#ifdef __cplusplus
};
#endif
